@@ -7,18 +7,14 @@ require Exporter;
 @EXPORT = qw(lock unlock lock_rename);
 
 use Carp;
-
-#
-# It would be nice if I could use fcntl.ph and
-# errno.ph, but alas, that isn't safe.
-#
 use POSIX qw(EAGAIN EACCES EWOULDBLOCK ENOENT EEXIST O_EXCL O_CREAT O_RDWR); 
 use Fcntl qw(LOCK_SH LOCK_EX LOCK_NB LOCK_UN);
+use IO::File;
 
 use vars qw($VERSION $debug $av0debug);
 
 BEGIN	{
-	$VERSION = 101.06_05_01;
+	$VERSION = 2008.01;
 	$debug = 0;
 	$av0debug = 0;
 }
@@ -32,8 +28,6 @@ my %shared;
 my %pid;
 my %rm;
 
-my $gensym = "sym0000";
-
 sub new
 {
 	my ($pkg, $file, $shared, $nonblocking) = @_;
@@ -51,8 +45,7 @@ sub lock
 {
 	my ($file, $shared, $nonblocking) = @_;
 
-	$gensym++;
-	my $f = "File::Flock::$gensym";
+	my $f = new IO::File;
 
 	my $created = 0;
 	my $previous = exists $locks{$file};
@@ -98,7 +91,7 @@ sub lock
 
 		my $ifile = (stat($file))[1];
 		my $ihandle;
-		eval "\$ihandle = (stat($f))[1]";
+		eval { $ihandle = (stat($f))[1] };
 		croak $@ if $@;
 
 		return 1 if defined $ifile 
@@ -171,7 +164,8 @@ sub unlock
 	my $unlocked = 0;
 
 
-	if ($created and -s $file == 0) {
+	my $size = -s $file;
+	if ($created && defined($size) && $size == 0) {
 		if ($shared{$file}) {
 			$unlocked = 
 				&background_remove($lockHandle{$file}, $file);
@@ -238,8 +232,7 @@ END {
 
 	my %bgrm;
 	for my $file (keys %rm) {
-		$gensym++;
-		my $f = "File::Flock::$gensym";
+		my $f = new IO::File;
 		if (sysopen($f, $file, O_RDWR)) {
 			if (flock($f, LOCK_EX|LOCK_NB)) {
 				unlink($file)
@@ -262,8 +255,7 @@ END {
 			croak "cannot fork" unless defined $pid;
 			unless ($pid) {
 				for my $file (keys %bgrm) {
-					$gensym++;
-					my $f = "File::Flock::$gensym";
+					my $f = new IO::File;
 					if (sysopen($f, $file, O_RDWR)) {
 						if (flock($f, LOCK_EX)) {
 							unlink($file)
@@ -318,12 +310,18 @@ Locks can be created by new'ing a B<File::Flock> object.  Such locks
 are automatically removed when the object goes out of scope.  The
 B<unlock()> method may also be used.
 
-B<lock_rename()> is used to tell File::Flock when a file has been renamed
-(and thus the locking data that is stored based on the filename should
-be moved to a new name).
+B<lock_rename()> is used to tell File::Flock when a file has been
+renamed (and thus the internal locking data that is stored based
+on the filename should be moved to a new name).  B<unlock()> the
+new name rather than the original name.
+
+=head1 LICENSE
+
+File::Flock may be used/modified/distibuted on the same terms
+as perl itself.  
 
 =head1 AUTHOR
 
-David Muir Sharnoff, <muir@idiom.com>
+David Muir Sharnoff <muir@idiom.org>
 
 
